Installation
============

pip install
-----------

``voxcell`` is distributed as a Python package available at BBP devpi server:

.. code-block:: console

    $ pip install -i https://bbpteam.epfl.ch/repository/devpi/simple/ voxcell
